@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.5.29"
-#define MARIADB_BASE_VERSION		"mariadb-10.5"
-#define MARIADB_VERSION_ID		100529
+#define MARIADB_CLIENT_VERSION_STR	"10.6.10"
+#define MARIADB_BASE_VERSION		"mariadb-10.6"
+#define MARIADB_VERSION_ID		100610
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100529
-#define MYSQL_SERVER_VERSION            "10.5.29-MariaDB"
+#define MYSQL_VERSION_ID                100610
+#define MYSQL_SERVER_VERSION            "10.6.10-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.29"
-#define MARIADB_PACKAGE_VERSION_ID 30129
-#define MARIADB_SYSTEM_TYPE "NetBSD"
-#define MARIADB_MACHINE_TYPE "earmv6hf"
+#define MARIADB_PACKAGE_VERSION "3.3.2"
+#define MARIADB_PACKAGE_VERSION_ID 30302
+#define MARIADB_SYSTEM_TYPE "Linux"
+#define MARIADB_MACHINE_TYPE "x86_64"
 #define MARIADB_PLUGINDIR "/usr/pkg/lib/mysql/plugin"
 
 /* mysqld compile time options */
