@@ -18,11 +18,11 @@
 #define DOT_FRM_VERSION 6
 /* Headers we may want to use. */
 #define STDC_HEADERS 1
-/* #undef _GNU_SOURCE */
-/* #undef HAVE_ALLOCA_H */
+#define _GNU_SOURCE 1
+#define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
-/* #undef HAVE_ASM_TERMBITS_H */
-/* #undef HAVE_CRYPT_H */
+#define HAVE_ASM_TERMBITS_H 1
+#define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
 /* #undef HAVE_BFD_H */
 /* #undef HAVE_NDIR_H */
@@ -33,21 +33,21 @@
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
-/* #undef HAVE_FPU_CONTROL_H */
-/* #undef HAVE_GETMNTENT */
+#define HAVE_FPU_CONTROL_H 1
+#define HAVE_GETMNTENT 1
 /* #undef HAVE_GETMNTENT_IN_SYS_MNTAB */
-#define HAVE_GETMNTINFO 1
+/* #undef HAVE_GETMNTINFO */
 /* #undef HAVE_GETMNTINFO64 */
-#define HAVE_GETMNTINFO_TAKES_statvfs 1
+/* #undef HAVE_GETMNTINFO_TAKES_statvfs */
 #define HAVE_GRP_H 1
 /* #undef HAVE_IA64INTRIN_H */
-#define HAVE_IEEEFP_H 1
+/* #undef HAVE_IEEEFP_H */
 #define HAVE_INTTYPES_H 1
-#define HAVE_KQUEUE 1
+/* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
 #define HAVE_LINK_H 1
-/* #undef HAVE_LINUX_UNISTD_H */
-/* #undef HAVE_LINUX_MMAN_H */
+#define HAVE_LINUX_UNISTD_H 1
+#define HAVE_LINUX_MMAN_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -70,17 +70,16 @@
 #define HAVE_SYS_FILE_H 1
 /* #undef HAVE_SYS_FPU_H */
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_MALLOC_H 1
+/* #undef HAVE_SYS_MALLOC_H */
 #define HAVE_SYS_MMAN_H 1
-/* #undef HAVE_SYS_MNTENT_H */
 /* #undef HAVE_SYS_NDIR_H */
 /* #undef HAVE_SYS_PTE_H */
 /* #undef HAVE_SYS_PTEM_H */
-/* #undef HAVE_SYS_PRCTL_H */
+#define HAVE_SYS_PRCTL_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
 #define HAVE_SYS_SOCKET_H 1
-#define HAVE_SYS_SOCKIO_H 1
+/* #undef HAVE_SYS_SOCKIO_H */
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
@@ -96,7 +95,7 @@
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
-/* #undef HAVE_TERMIO_H */
+#define HAVE_TERMIO_H 1
 #define HAVE_TERMCAP_H 1
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
@@ -107,8 +106,9 @@
 #define HAVE_SYS_PARAM_H 1
 
 /* Libraries */
-#define HAVE_LIBWRAP 1
+/* #undef HAVE_LIBWRAP */
 /* #undef HAVE_SYSTEMD */
+/* #undef HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -120,8 +120,8 @@
 
 #define FIONREAD_IN_SYS_IOCTL 1
 #define GWINSZ_IN_SYS_IOCTL 1
-#define TIOCSTAT_IN_SYS_IOCTL 1
-#define FIONREAD_IN_SYS_FILIO 1
+/* #undef TIOCSTAT_IN_SYS_IOCTL */
+/* #undef FIONREAD_IN_SYS_FILIO */
 
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
@@ -132,7 +132,7 @@
 #define HAVE_INDEX 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_CRYPT 1
-/* #undef HAVE_CUSERID */
+#define HAVE_CUSERID 1
 #define HAVE_DLADDR 1
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
@@ -142,10 +142,10 @@
 #define HAVE_DECL_FDATASYNC 1
 #define HAVE_FEDISABLEEXCEPT 1
 #define HAVE_FESETROUND 1
-#define HAVE_FP_EXCEPT 1
+/* #undef HAVE_FP_EXCEPT */
 #define HAVE_FSEEKO 1
 #define HAVE_FSYNC 1
-/* #undef HAVE_FTIME */
+#define HAVE_FTIME 1
 #define HAVE_GETIFADDRS 1
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
@@ -168,14 +168,13 @@
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
-/* #undef HAVE_MEMALIGN */
 /* #define HAVE_MLOCK 1 see Bug#54662 */
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
-/* #undef HAVE_MALLINFO */
-/* #undef HAVE_MALLINFO2 */
+#define HAVE_MALLINFO 1
+#define HAVE_MALLINFO2 1
 /* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -183,11 +182,11 @@
 #define HAVE_MKOSTEMP 1
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
-/* #undef HAVE_MMAP64 */
+#define HAVE_MMAP64 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
-/* #undef HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE */
+#define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
@@ -195,7 +194,6 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
-#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -203,10 +201,10 @@
 #define HAVE_PTHREAD_RWLOCK_RDLOCK 1
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_YIELD_NP */
-/* #undef HAVE_PTHREAD_YIELD_ZERO_ARG */
+#define HAVE_PTHREAD_YIELD_ZERO_ARG 1
 #define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
 #define HAVE_PUTENV 1
-#define HAVE_READDIR_R 1
+/* #undef HAVE_READDIR_R */
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -215,7 +213,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
-/* #undef HAVE_SETMNTENT */
+#define HAVE_SETMNTENT 1
 #define HAVE_SETUPTERM 1
 #define HAVE_SIGSET 1
 #define HAVE_SIGACTION 1
@@ -223,6 +221,7 @@
 #define HAVE_SIGWAIT 1
 #define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
+#define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
 #define HAVE_STRERROR 1
 #define HAVE_STRCOLL 1
@@ -233,10 +232,11 @@
 #define HAVE_STRTOUL 1
 #define HAVE_STRTOULL 1
 /* #undef HAVE_TELL */
+/* #undef HAVE_THR_SETCONCURRENCY */
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-/* #undef HAVE_VIDATTR */
+#define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
 #define HAVE_VASPRINTF 1
 #define HAVE_VSNPRINTF 1
@@ -251,11 +251,14 @@
 /* #undef HAVE_PRINTSTACK */
 #define HAVE_IPV6 1
 /* #undef ss_family */
-#define HAVE_SOCKADDR_IN_SIN_LEN 1
-#define HAVE_SOCKADDR_IN6_SIN6_LEN 1
+/* #undef HAVE_SOCKADDR_IN_SIN_LEN */
+/* #undef HAVE_SOCKADDR_IN6_SIN6_LEN */
 #define STRUCT_TIMESPEC_HAS_TV_SEC 1
 #define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 
+#define USE_MB 1
+#define USE_MB_IDENT 1
+
 /* this means that valgrind headers and macros are available */
 /* #undef HAVE_VALGRIND_MEMCHECK_H */
 
@@ -326,7 +329,7 @@
 
 #define RETSIGTYPE void
 #define VOID_SIGHANDLER 1
-/* #undef HAVE_SIGHANDLER_T */
+#define HAVE_SIGHANDLER_T 1
 #define STRUCT_RLIMIT struct rlimit
 
 #ifdef __APPLE__
@@ -334,7 +337,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -347,7 +350,7 @@
 #endif
 
 
-/* #undef TARGET_OS_LINUX */
+#define TARGET_OS_LINUX 1
 
 #define HAVE_WCTYPE_H 1
 #define HAVE_WCHAR_H 1
@@ -394,9 +397,9 @@
 
 #define STACK_DIRECTION -1
 
-#define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "sparc64"
-#define DEFAULT_MACHINE "sparc64"
+#define SYSTEM_TYPE "Linux"
+#define MACHINE_TYPE "x86_64"
+#define DEFAULT_MACHINE "x86_64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -431,7 +434,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -451,8 +454,8 @@
 #define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
 #define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
 
-#define USE_MB
-#define USE_MB_IDENT
+#define USE_MB 1
+#define USE_MB_IDENT 1
 
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
@@ -499,7 +502,6 @@
 #define HAVE_COMPRESS 1
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
-#define HAVE_des 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -531,17 +533,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 29
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 10
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.29"
+#define PACKAGE_STRING "MySQL Server 10.6.10"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.29"
-#define VERSION "10.5.29"
+#define PACKAGE_VERSION "10.6.10"
+#define VERSION "10.6.10"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
